<a id="packages.valory.connections.abci.tests.test_fuzz.mock_node.node"></a>

# packages.valory.connections.abci.tests.test`_`fuzz.mock`_`node.node

Used for mocking a tendermint node

<a id="packages.valory.connections.abci.tests.test_fuzz.mock_node.node.MockNode"></a>

## MockNode Objects

```python
class MockNode()
```

Mocks a Tendermint Node

<a id="packages.valory.connections.abci.tests.test_fuzz.mock_node.node.MockNode.connect"></a>

#### connect

```python
def connect() -> None
```

Connect the node.

<a id="packages.valory.connections.abci.tests.test_fuzz.mock_node.node.MockNode.disconnect"></a>

#### disconnect

```python
def disconnect() -> None
```

Disconnect the node.

